# git.py: Specialization of `describe' for Git.
# Copyright (C) 2013  Stephen Compall

# Julython-commit is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.

# Julython-commit is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Julython-commit.  If not, see <http://www.gnu.org/licenses/>.

from datetime import datetime
from functools import partial
import re

from dulwich import repo as gitrepo
from julythoncommit.describe import Config
from julythoncommit.util import infer_origin, key_error_safe, \
    parse_author

_origin_patterns = [(re.compile(reg), exps) for reg, exps in [
    (r'git://gitorious.org/([^/]+)/(.*)\.git',
     (ur'https://gitorious.org/\1/\2', ur'\2',
      r'https://gitorious.org/\1/\2/commit/%s')),
]]

def config(dirpath='.'):
    repo = gitrepo.Repo(dirpath)
    repoconf = key_error_safe(repo.get_config_stack().get)
    origin_url = repoconf(('remote', 'origin'), 'url')
    inferred_url, inferred_name, inferred_commitpat = (
        origin_url and _infer_origin(origin_url) or (None, None, None))
    c = Config(repoconf('julython', 'repo_url') or inferred_url,
               repoconf('julython', 'repo_name') or inferred_name,
               repo.get_named_file('description').read(),
               repoconf('julython', 'commit_pattern')
               or inferred_commitpat)
    c.repo = repo
    return c

def revspec(conf, revinfo):
    pass                        # TODO

def _dulwich_commit_to_revision(sha, ci):
    name, email = parse_author(ci.author)
    # ci.author_time => 1372560321, ci.author_timezone => -14400
    # f(1372560321, -14400) => Sat Jun 29 22:45:21 2013 -0400
    # TODO 2nd arg to fromtimestamp
    return Revision(email, name, sha, ci.message,
                    datetime.fromtimestamp(ci.author_time))

_infer_origin = partial(infer_origin, _origin_patterns)

# git.py ends here
