# tests.py: Unit tests.
# Copyright (C) 2013  Stephen Compall

# Julython-commit is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.

# Julython-commit is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Julython-commit.  If not, see <http://www.gnu.org/licenses/>.

from julythoncommit import describe, git, util
from unittest import TestCase

class Git(TestCase):
    def test_pattern_infer(self):
        self.assertIs(None, git._infer_origin('blahblah'))
        self.assertEquals(
            (u'https://gitorious.org/mediagoblin/mediagoblin',
             u'mediagoblin',
             'https://gitorious.org/mediagoblin/mediagoblin/commit/%s'),
            git._infer_origin('git://gitorious.org/mediagoblin/mediagoblin.git'))

class Util(TestCase):
    def test_key_error_safe(self):
        # key_error_safe(id) = id
        self.assertEquals(42, util.key_error_safe(lambda x:x)(42))

    def test_parse_author(self):
        self.assertEquals(
            (u'John Doe', u'john@doe.org'),
            util.parse_author(u' John Doe <john@doe.org> '))
        self.assertEquals(
            (None, u'john@doe.org'),
            util.parse_author(u'<john@doe.org>'))
        self.assertEquals(
            (u'John Doe', None),
            util.parse_author(u'John Doe '))
        self.assertEquals(
            (None, None), util.parse_author(u'  '))
        self.assertEquals(
            (u'X', u'john@doe.org'),
            util.parse_author(u' X <john@doe.org> '))

# tests.py ends here
