# util.py: Arbitrary utilities.
# Copyright (C) 2013  Stephen Compall

# Julython-commit is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.

# Julython-commit is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Julython-commit.  If not, see <http://www.gnu.org/licenses/>.

import re

def infer_origin(patterns, origin_url):
    """Find a regex key in the alist ``patterns`` matching
    ``origin_url``, mapping the associated list of substitutions over
    ``origin_url``, or return ``None``.
    """
    for reg, exps in patterns:
        if reg.match(origin_url):
            return tuple(reg.sub(exp, origin_url) for exp in exps)

def key_error_safe(f, otherwise=None):
    """A variant of ``f``, a function, in which ``KeyError``s are
    masked to ``otherwise``, which is ``None`` by default.
    """
    def fsafe(*args, **kwargs):
        try:
            return f(*args, **kwargs)
        except KeyError:
            return otherwise
    return fsafe

_parse_author_re = re.compile(ur'(\S(?:.*?\S)?)\s*(?:<(.+)>)')

def parse_author(auth):
    """Split a string like "John Doe <john@doe.org>" into name and
    email.
    """
    m = _parse_author_re.search(auth)
    if m:
        return m.group(1), m.group(2)

# util.py ends here
